<?php

namespace Drupal\mailgroup_mailgun\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Entity\EntityStorageException;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Drupal\mailgroup\Entity\MailGroup;
use Drupal\mailgroup\Entity\MailGroupMessage;

/**
 * Controller for Mail group Mailgun routes.
 */
class MailgunController extends ControllerBase {

  use StringTranslationTrait;

  /**
   * Responds to POST requests.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   An empty response.
   */
  public function receive(Request $request) {
    $recipient = $request->request->get('recipient');
    $group = MailGroup::loadByEmail($recipient);

    if ($group) {
      $values = [
        'gid' => $group->id(),
        'sender' => $request->request->get('sender'),
        'subject' => $request->request->get('subject'),
        'body' => $request->request->get('stripped-text'),
      ];
      $message = MailGroupMessage::create($values);

      try {
        $message->save();
      }

      catch (EntityStorageException $e) {
        $this->getLogger('mailgroup_mailgun')->notice($e->getMessage());
        $this->getLogger('mailgroup_mailgun')
          ->error($this->t('Unable to save message to @group', ['@group' => $group->getName()]));
      }
    }

    return new Response();
  }

}
