<?php

namespace Drupal\mailgroup_mailgun\Plugin\Mailgroup\Connection;

use Drupal\mailgroup\ConnectionBase;
use Mailgun\Mailgun as MailgunPHP;
use Mailgun\Exception\HttpClientException;

/**
 * Basic server connection plugin.
 *
 * @Plugin(
 *   id = "mailgun",
 *   label = @Translation("Mailgun")
 * )
 */
class Mailgun extends ConnectionBase {

  /**
   * {@inheritdoc}
   */
  public function getFields() {
    $config = $this->configuration;

    $fields['domain'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Domain'),
      '#default_value' => isset($config['domain']) ? $config['domain'] : NULL,
    ];

    $fields['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API key'),
      '#default_value' => isset($config['api_key']) ? $config['api_key'] : NULL,
    ];

    return $fields;
  }

  /**
   * {@inheritdoc}
   */
  public function testConnection() {
    $config = $this->configuration;
    $mailgun = MailgunPHP::create($config['api_key']);

    try {
      $mailgun->domains()->verify($config['domain']);
    }

    catch (HttpClientException $e) {
      return FALSE;
    }

    return TRUE;
  }

}
